Documentation
¶
Index ¶
- func GetEventDrivenIngestionResource(context context.Context, namespacedName types.NamespacedName, ...) (*v1alpha1.DicomEventDrivenIngestion, error)
- func GetEventProcessorServiceEndpoint(cr *v1alpha1.DicomEventDrivenIngestion) string
- func GetWadoEndpoints(context context.Context, client client.Client, ...) (string, string)
- type DicomEventBridgeReconciler
- func (r *DicomEventBridgeReconciler) GetDesiredState(currentState *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.DesiredResourceState
- func (i *DicomEventBridgeReconciler) GetEdgeLocationConfigDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
- func (i *DicomEventBridgeReconciler) GetEventBridgeDeploymentDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
- func (i *DicomEventBridgeReconciler) GetEventBridgeServiceDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
- func (i *DicomEventBridgeReconciler) GetEventDrivenIngestionDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
- func (i *DicomEventBridgeReconciler) GetNatsConfigDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
- func (i *DicomEventBridgeReconciler) GetNatsTokenSecretDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
- func (r *DicomEventBridgeReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DicomEventBridgeReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DicomEventBridgeState
- type DicomEventDrivenIngestionReconciler
- func (i *DicomEventDrivenIngestionReconciler) GetDatabaseConfigDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
- func (i *DicomEventDrivenIngestionReconciler) GetDatabaseSecretDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
- func (r *DicomEventDrivenIngestionReconciler) GetDesiredState(currentState *DicomEventDrivenIngestionState, ...) common.DesiredResourceState
- func (i *DicomEventDrivenIngestionReconciler) GetEventBrokerDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
- func (i *DicomEventDrivenIngestionReconciler) GetEventProcessorServiceDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
- func (i *DicomEventDrivenIngestionReconciler) GetImageStoredTriggerDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
- func (r *DicomEventDrivenIngestionReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DicomEventDrivenIngestionReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DicomEventDrivenIngestionState
- type DicomInstanceBindingReconciler
- func (r *DicomInstanceBindingReconciler) GetDesiredState(currentState *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.DesiredResourceState
- func (i *DicomInstanceBindingReconciler) GetInstanceBindingConfigDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
- func (i *DicomInstanceBindingReconciler) GetInstanceBindingSecretDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
- func (i *DicomInstanceBindingReconciler) GetInstanceBindingServiceDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
- func (i *DicomInstanceBindingReconciler) GetInstanceBindingTriggerDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
- func (r *DicomInstanceBindingReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DicomInstanceBindingReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DicomInstanceBindingState
- type DicomStudyBindingReconciler
- func (r *DicomStudyBindingReconciler) GetDesiredState(currentState *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.DesiredResourceState
- func (i *DicomStudyBindingReconciler) GetStudyBindingConfigDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
- func (i *DicomStudyBindingReconciler) GetStudyBindingSecretDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
- func (i *DicomStudyBindingReconciler) GetStudyBindingServiceDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
- func (i *DicomStudyBindingReconciler) GetStudyBindingSinkBindingDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
- func (i *DicomStudyBindingReconciler) GetStudyBindingTriggerDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
- func (r *DicomStudyBindingReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DicomStudyBindingReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DicomStudyBindingState
- type DicomwebIngestionServiceReconciler
- func (i *DicomwebIngestionServiceReconciler) GetBucketConfigDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
- func (i *DicomwebIngestionServiceReconciler) GetBucketSecretDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
- func (r *DicomwebIngestionServiceReconciler) GetDesiredState(currentState *DicomwebIngestionServiceState, ...) common.DesiredResourceState
- func (i *DicomwebIngestionServiceReconciler) GetStowServiceDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
- func (i *DicomwebIngestionServiceReconciler) GetStowSinkBindingDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
- func (i *DicomwebIngestionServiceReconciler) GetWadoServiceDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
- func (r *DicomwebIngestionServiceReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DicomwebIngestionServiceReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DicomwebIngestionServiceState
- type DimseIngestionServiceReconciler
- func (i *DimseIngestionServiceReconciler) GetBucketConfigDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
- func (i *DimseIngestionServiceReconciler) GetBucketSecretDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
- func (r *DimseIngestionServiceReconciler) GetDesiredState(currentState *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.DesiredResourceState
- func (i *DimseIngestionServiceReconciler) GetDimseConfigDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
- func (i *DimseIngestionServiceReconciler) GetDimseIngestionServiceDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
- func (i *DimseIngestionServiceReconciler) GetNatsConfigDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
- func (r *DimseIngestionServiceReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DimseIngestionServiceReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DimseIngestionServiceState
- type DimseProxyReconciler
- func (r *DimseProxyReconciler) GetDesiredState(currentState *DimseProxyState, cr *v1alpha1.DimseProxy) common.DesiredResourceState
- func (i *DimseProxyReconciler) GetDimseConfigDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
- func (i *DimseProxyReconciler) GetDimseProxyDeploymentDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
- func (i *DimseProxyReconciler) GetDimseProxyServiceDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
- func (i *DimseProxyReconciler) GetNatsConfigDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
- func (i *DimseProxyReconciler) GetNatsTokenSecretDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
- func (r *DimseProxyReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *DimseProxyReconciler) SetupWithManager(mgr ctrl.Manager) error
- type DimseProxyState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEventDrivenIngestionResource ¶
func GetEventDrivenIngestionResource(context context.Context, namespacedName types.NamespacedName, controllerClient client.Client) (*v1alpha1.DicomEventDrivenIngestion, error)
func GetEventProcessorServiceEndpoint ¶
func GetEventProcessorServiceEndpoint(cr *v1alpha1.DicomEventDrivenIngestion) string
Types ¶
type DicomEventBridgeReconciler ¶
DicomEventBridgeReconciler reconciles a DicomEventBridge object
func (*DicomEventBridgeReconciler) GetDesiredState ¶
func (r *DicomEventBridgeReconciler) GetDesiredState(currentState *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.DesiredResourceState
func (*DicomEventBridgeReconciler) GetEdgeLocationConfigDesiredState ¶
func (i *DicomEventBridgeReconciler) GetEdgeLocationConfigDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
func (*DicomEventBridgeReconciler) GetEventBridgeDeploymentDesiredState ¶
func (i *DicomEventBridgeReconciler) GetEventBridgeDeploymentDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
func (*DicomEventBridgeReconciler) GetEventBridgeServiceDesiredState ¶
func (i *DicomEventBridgeReconciler) GetEventBridgeServiceDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
func (*DicomEventBridgeReconciler) GetEventDrivenIngestionDesiredState ¶
func (i *DicomEventBridgeReconciler) GetEventDrivenIngestionDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
func (*DicomEventBridgeReconciler) GetNatsConfigDesiredState ¶
func (i *DicomEventBridgeReconciler) GetNatsConfigDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
func (*DicomEventBridgeReconciler) GetNatsTokenSecretDesiredState ¶
func (i *DicomEventBridgeReconciler) GetNatsTokenSecretDesiredState(state *DicomEventBridgeState, cr *v1alpha1.DicomEventBridge) common.ControllerAction
func (*DicomEventBridgeReconciler) Reconcile ¶
func (r *DicomEventBridgeReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the DicomEventBridge object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.10.0/pkg/reconcile
func (*DicomEventBridgeReconciler) SetupWithManager ¶
func (r *DicomEventBridgeReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DicomEventBridgeState ¶
type DicomEventBridgeState struct {
client.Client
Scheme *runtime.Scheme
EventDrivenIngestion *v1alpha1.DicomEventDrivenIngestion
NatsTokenSecret *corev1.Secret
NatsConfig *corev1.ConfigMap
EdgeLocationConfig *corev1.ConfigMap
EventBridgeDeployment *appsv1.Deployment
EventBridgeService *corev1.Service
}
func NewDicomEventBridgeState ¶
func NewDicomEventBridgeState(client client.Client, scheme *runtime.Scheme) *DicomEventBridgeState
func (*DicomEventBridgeState) IsResourcesReady ¶
func (i *DicomEventBridgeState) IsResourcesReady(resource client.Object) (bool, error)
type DicomEventDrivenIngestionReconciler ¶
DicomEventDrivenIngestionReconciler reconciles a DicomEventDrivenIngestion object
func (*DicomEventDrivenIngestionReconciler) GetDatabaseConfigDesiredState ¶
func (i *DicomEventDrivenIngestionReconciler) GetDatabaseConfigDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
func (*DicomEventDrivenIngestionReconciler) GetDatabaseSecretDesiredState ¶
func (i *DicomEventDrivenIngestionReconciler) GetDatabaseSecretDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
func (*DicomEventDrivenIngestionReconciler) GetDesiredState ¶
func (r *DicomEventDrivenIngestionReconciler) GetDesiredState(currentState *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.DesiredResourceState
func (*DicomEventDrivenIngestionReconciler) GetEventBrokerDesiredState ¶
func (i *DicomEventDrivenIngestionReconciler) GetEventBrokerDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
func (*DicomEventDrivenIngestionReconciler) GetEventProcessorServiceDesiredState ¶
func (i *DicomEventDrivenIngestionReconciler) GetEventProcessorServiceDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
func (*DicomEventDrivenIngestionReconciler) GetImageStoredTriggerDesiredState ¶
func (i *DicomEventDrivenIngestionReconciler) GetImageStoredTriggerDesiredState(state *DicomEventDrivenIngestionState, cr *v1alpha1.DicomEventDrivenIngestion) common.ControllerAction
func (*DicomEventDrivenIngestionReconciler) Reconcile ¶
func (r *DicomEventDrivenIngestionReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.7.2/pkg/reconcile
func (*DicomEventDrivenIngestionReconciler) SetupWithManager ¶
func (r *DicomEventDrivenIngestionReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DicomEventDrivenIngestionState ¶
type DicomEventDrivenIngestionState struct {
client.Client
Scheme *runtime.Scheme
DatabaseSecret *corev1.Secret
DatabaseConfig *corev1.ConfigMap
EventProcessorService *kservingv1.Service
EventBroker *keventingv1.Broker
ImageStoredTrigger *keventingv1.Trigger
}
func NewDicomEventDrivenIngestionState ¶
func NewDicomEventDrivenIngestionState(client client.Client, scheme *runtime.Scheme) *DicomEventDrivenIngestionState
func (*DicomEventDrivenIngestionState) IsResourcesReady ¶
func (i *DicomEventDrivenIngestionState) IsResourcesReady(resource client.Object) (bool, error)
type DicomInstanceBindingReconciler ¶
DicomInstanceBindingReconciler reconciles a DicomInstanceBinding object
func (*DicomInstanceBindingReconciler) GetDesiredState ¶
func (r *DicomInstanceBindingReconciler) GetDesiredState(currentState *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.DesiredResourceState
func (*DicomInstanceBindingReconciler) GetInstanceBindingConfigDesiredState ¶
func (i *DicomInstanceBindingReconciler) GetInstanceBindingConfigDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
func (*DicomInstanceBindingReconciler) GetInstanceBindingSecretDesiredState ¶
func (i *DicomInstanceBindingReconciler) GetInstanceBindingSecretDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
func (*DicomInstanceBindingReconciler) GetInstanceBindingServiceDesiredState ¶
func (i *DicomInstanceBindingReconciler) GetInstanceBindingServiceDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
func (*DicomInstanceBindingReconciler) GetInstanceBindingTriggerDesiredState ¶
func (i *DicomInstanceBindingReconciler) GetInstanceBindingTriggerDesiredState(state *DicomInstanceBindingState, cr *v1alpha1.DicomInstanceBinding) common.ControllerAction
func (*DicomInstanceBindingReconciler) Reconcile ¶
func (r *DicomInstanceBindingReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.7.2/pkg/reconcile
func (*DicomInstanceBindingReconciler) SetupWithManager ¶
func (r *DicomInstanceBindingReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DicomInstanceBindingState ¶
type DicomInstanceBindingState struct {
client.Client
Scheme *runtime.Scheme
InstanceBindingSecret *corev1.Secret
InstanceBindingConfig *corev1.ConfigMap
InstanceBindingService *kservingv1.Service
InstanceBindingTrigger *keventingv1.Trigger
}
func NewDicomInstanceBindingState ¶
func NewDicomInstanceBindingState(client client.Client, scheme *runtime.Scheme) *DicomInstanceBindingState
func (*DicomInstanceBindingState) IsResourcesReady ¶
func (i *DicomInstanceBindingState) IsResourcesReady(resource client.Object) (bool, error)
type DicomStudyBindingReconciler ¶
DicomStudyBindingReconciler reconciles a DicomStudyBinding object
func (*DicomStudyBindingReconciler) GetDesiredState ¶
func (r *DicomStudyBindingReconciler) GetDesiredState(currentState *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.DesiredResourceState
func (*DicomStudyBindingReconciler) GetStudyBindingConfigDesiredState ¶
func (i *DicomStudyBindingReconciler) GetStudyBindingConfigDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
func (*DicomStudyBindingReconciler) GetStudyBindingSecretDesiredState ¶
func (i *DicomStudyBindingReconciler) GetStudyBindingSecretDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
func (*DicomStudyBindingReconciler) GetStudyBindingServiceDesiredState ¶
func (i *DicomStudyBindingReconciler) GetStudyBindingServiceDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
func (*DicomStudyBindingReconciler) GetStudyBindingSinkBindingDesiredState ¶
func (i *DicomStudyBindingReconciler) GetStudyBindingSinkBindingDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
func (*DicomStudyBindingReconciler) GetStudyBindingTriggerDesiredState ¶
func (i *DicomStudyBindingReconciler) GetStudyBindingTriggerDesiredState(state *DicomStudyBindingState, cr *v1alpha1.DicomStudyBinding) common.ControllerAction
func (*DicomStudyBindingReconciler) Reconcile ¶
func (r *DicomStudyBindingReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.7.2/pkg/reconcile
func (*DicomStudyBindingReconciler) SetupWithManager ¶
func (r *DicomStudyBindingReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DicomStudyBindingState ¶
type DicomStudyBindingState struct {
client.Client
Scheme *runtime.Scheme
StudyBindingSecret *corev1.Secret
StudyBindingConfig *corev1.ConfigMap
StudyBindingService *kservingv1.Service
StudyBindingSinkBinding *ksourcesv1.SinkBinding
StudyBindingTrigger *keventingv1.Trigger
}
func NewDicomStudyBindingState ¶
func NewDicomStudyBindingState(client client.Client, scheme *runtime.Scheme) *DicomStudyBindingState
func (*DicomStudyBindingState) IsResourcesReady ¶
func (i *DicomStudyBindingState) IsResourcesReady(resource client.Object) (bool, error)
type DicomwebIngestionServiceReconciler ¶
DicomwebIngestionServiceReconciler reconciles a DicomwebIngestionService object
func (*DicomwebIngestionServiceReconciler) GetBucketConfigDesiredState ¶
func (i *DicomwebIngestionServiceReconciler) GetBucketConfigDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
func (*DicomwebIngestionServiceReconciler) GetBucketSecretDesiredState ¶
func (i *DicomwebIngestionServiceReconciler) GetBucketSecretDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
func (*DicomwebIngestionServiceReconciler) GetDesiredState ¶
func (r *DicomwebIngestionServiceReconciler) GetDesiredState(currentState *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.DesiredResourceState
func (*DicomwebIngestionServiceReconciler) GetStowServiceDesiredState ¶
func (i *DicomwebIngestionServiceReconciler) GetStowServiceDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
func (*DicomwebIngestionServiceReconciler) GetStowSinkBindingDesiredState ¶
func (i *DicomwebIngestionServiceReconciler) GetStowSinkBindingDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
func (*DicomwebIngestionServiceReconciler) GetWadoServiceDesiredState ¶
func (i *DicomwebIngestionServiceReconciler) GetWadoServiceDesiredState(state *DicomwebIngestionServiceState, cr *v1alpha1.DicomwebIngestionService) common.ControllerAction
func (*DicomwebIngestionServiceReconciler) Reconcile ¶
func (r *DicomwebIngestionServiceReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.7.2/pkg/reconcile
func (*DicomwebIngestionServiceReconciler) SetupWithManager ¶
func (r *DicomwebIngestionServiceReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DicomwebIngestionServiceState ¶
type DicomwebIngestionServiceState struct {
client.Client
Scheme *runtime.Scheme
BucketSecret *corev1.Secret
BucketConfig *corev1.ConfigMap
StowService *kservingv1.Service
WadoService *kservingv1.Service
StowSinkBinding *ksourcesv1.SinkBinding
}
func NewDicomwebIngestionServiceState ¶
func NewDicomwebIngestionServiceState(client client.Client, scheme *runtime.Scheme) *DicomwebIngestionServiceState
func (*DicomwebIngestionServiceState) IsResourcesReady ¶
func (i *DicomwebIngestionServiceState) IsResourcesReady(resource client.Object) (bool, error)
type DimseIngestionServiceReconciler ¶
DimseIngestionServiceReconciler reconciles a DimseIngestionService object
func (*DimseIngestionServiceReconciler) GetBucketConfigDesiredState ¶
func (i *DimseIngestionServiceReconciler) GetBucketConfigDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
func (*DimseIngestionServiceReconciler) GetBucketSecretDesiredState ¶
func (i *DimseIngestionServiceReconciler) GetBucketSecretDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
func (*DimseIngestionServiceReconciler) GetDesiredState ¶
func (r *DimseIngestionServiceReconciler) GetDesiredState(currentState *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.DesiredResourceState
func (*DimseIngestionServiceReconciler) GetDimseConfigDesiredState ¶
func (i *DimseIngestionServiceReconciler) GetDimseConfigDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
func (*DimseIngestionServiceReconciler) GetDimseIngestionServiceDesiredState ¶
func (i *DimseIngestionServiceReconciler) GetDimseIngestionServiceDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
func (*DimseIngestionServiceReconciler) GetNatsConfigDesiredState ¶
func (i *DimseIngestionServiceReconciler) GetNatsConfigDesiredState(state *DimseIngestionServiceState, cr *v1alpha1.DimseIngestionService) common.ControllerAction
func (*DimseIngestionServiceReconciler) Reconcile ¶
func (r *DimseIngestionServiceReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.7.2/pkg/reconcile
func (*DimseIngestionServiceReconciler) SetupWithManager ¶
func (r *DimseIngestionServiceReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DimseIngestionServiceState ¶
type DimseIngestionServiceState struct {
client.Client
Scheme *runtime.Scheme
BucketSecret *corev1.Secret
BucketConfig *corev1.ConfigMap
NatsConfig *corev1.ConfigMap
DimseConfig *corev1.ConfigMap
DimseIngestionDeployment *appsv1.Deployment
}
func NewDimseIngestionServiceState ¶
func NewDimseIngestionServiceState(client client.Client, scheme *runtime.Scheme) *DimseIngestionServiceState
func (*DimseIngestionServiceState) IsResourcesReady ¶
func (i *DimseIngestionServiceState) IsResourcesReady(resource client.Object) (bool, error)
type DimseProxyReconciler ¶
DimseProxyReconciler reconciles a DimseProxy object
func (*DimseProxyReconciler) GetDesiredState ¶
func (r *DimseProxyReconciler) GetDesiredState(currentState *DimseProxyState, cr *v1alpha1.DimseProxy) common.DesiredResourceState
func (*DimseProxyReconciler) GetDimseConfigDesiredState ¶
func (i *DimseProxyReconciler) GetDimseConfigDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
func (*DimseProxyReconciler) GetDimseProxyDeploymentDesiredState ¶
func (i *DimseProxyReconciler) GetDimseProxyDeploymentDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
func (*DimseProxyReconciler) GetDimseProxyServiceDesiredState ¶
func (i *DimseProxyReconciler) GetDimseProxyServiceDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
func (*DimseProxyReconciler) GetNatsConfigDesiredState ¶
func (i *DimseProxyReconciler) GetNatsConfigDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
func (*DimseProxyReconciler) GetNatsTokenSecretDesiredState ¶
func (i *DimseProxyReconciler) GetNatsTokenSecretDesiredState(state *DimseProxyState, cr *v1alpha1.DimseProxy) common.ControllerAction
func (*DimseProxyReconciler) Reconcile ¶
func (r *DimseProxyReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.7.2/pkg/reconcile
func (*DimseProxyReconciler) SetupWithManager ¶
func (r *DimseProxyReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type DimseProxyState ¶
type DimseProxyState struct {
client.Client
Scheme *runtime.Scheme
NatsTokenSecret *corev1.Secret
NatsConfig *corev1.ConfigMap
DimseConfig *corev1.ConfigMap
DimseProxyDeployment *appsv1.Deployment
DimseProxyService *corev1.Service
}
func NewDimseProxyState ¶
func NewDimseProxyState(client client.Client, scheme *runtime.Scheme) *DimseProxyState
func (*DimseProxyState) IsResourcesReady ¶
func (i *DimseProxyState) IsResourcesReady(resource client.Object) (bool, error)
Source Files
¶
- common.go
- dicomeventbridge_controller.go
- dicomeventbridge_reconciler.go
- dicomeventbridge_state.go
- dicomeventdriveningestion_controller.go
- dicomeventdriveningestion_reconciler.go
- dicomeventdriveningestion_state.go
- dicominstancebinding_controller.go
- dicominstancebinding_reconciler.go
- dicominstancebinding_state.go
- dicomstudybinding_controller.go
- dicomstudybinding_reconciler.go
- dicomstudybinding_state.go
- dicomwebingestionservice_controller.go
- dicomwebingestionservice_reconciler.go
- dicomwebingestionservice_state.go
- dimseingestionservice_controller.go
- dimseingestionservice_reconciler.go
- dimseingestionservice_state.go
- dimseproxy_controller.go
- dimseproxy_reconciler.go
- dimseproxy_state.go